/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_INCLUDE_SCREEN_CONNECTOR_LAUNCHER_SERVICE_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_INCLUDE_SCREEN_CONNECTOR_LAUNCHER_SERVICE_H_

#include <stdbool.h>
#include <stdint.h>

#include <Ecore_Wl2.h>
#include <tbm_surface.h>
#include <tizen.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_ERROR_NONE,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_ERROR_DISQUALIFIED,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_ERROR_WRONG_REQUEST,
} screen_connector_launcher_service_error_e;

typedef enum {
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_DIRECTION_FORWARD,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_DIRECTION_BACKWARD,
} screen_connector_launcher_service_direction_e;

typedef enum {
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_TYPE_REMOTE_SURFACE_TBM,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_TYPE_REMOTE_SURFACE_IMAGE_FILE,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_TYPE_SPLASH_SCREEN_IMAGE,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_TYPE_SPLASH_SCREEN_EDJE,
} screen_connector_launcher_service_image_type_e;

typedef void* screen_connector_launcher_service_h;

typedef void* screen_connector_launcher_service_image_h;

typedef void (*screen_connector_launcher_service_prepare_cb)(
  screen_connector_launcher_service_image_h image,
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_stop_cb)(
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_error_cb)(
  screen_connector_launcher_service_error_e error,
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_cleanup_cb)(
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_reset_cb)(
  uint32_t serial,
  void* user_data);

typedef struct {
  screen_connector_launcher_service_prepare_cb prepare;
  screen_connector_launcher_service_stop_cb stop;
  screen_connector_launcher_service_error_cb error;
  screen_connector_launcher_service_cleanup_cb cleanup;
  screen_connector_launcher_service_reset_cb reset;
} screen_connector_launcher_service_ops;

int screen_connector_launcher_service_create(
  Ecore_Wl2_Window* wl2_win,
  screen_connector_launcher_service_h* handle);

int screen_connector_launcher_service_destroy(
  screen_connector_launcher_service_h handle);

int screen_connector_launcher_service_set_ops(
  screen_connector_launcher_service_h handle,
  screen_connector_launcher_service_ops *ops,
  void* user_data);

int screen_connector_launcher_service_launch(
  screen_connector_launcher_service_h handle,
  const char* app_id,
  const char* inst_id,
  int pid,
  uint32_t serial);

int screen_connector_launcher_service_launch_with_shared_widget(
  screen_connector_launcher_service_h handle,
  const char* app_id,
  const char* inst_id,
  int pid,
  uint32_t serial);

int screen_connector_launcher_service_launching(
  screen_connector_launcher_service_h handle,
  uint32_t serial);

int screen_connector_launcher_service_launch_cancel(
  screen_connector_launcher_service_h handle,
  uint32_t serial);

int screen_connector_launcher_service_launch_done(
  screen_connector_launcher_service_h handle,
  uint32_t serial);

int screen_connector_launcher_service_image_get_direction(
  screen_connector_launcher_service_image_h handle,
  screen_connector_launcher_service_direction_e* direction);

int screen_connector_launcher_service_image_get_type(
  screen_connector_launcher_service_image_h handle,
  screen_connector_launcher_service_image_type_e *image_type);

int screen_connector_launcher_service_image_get_position_x(
  screen_connector_launcher_service_image_h handle,
  int32_t* x);

int screen_connector_launcher_service_image_get_position_y(
  screen_connector_launcher_service_image_h handle,
  int32_t* y);

int screen_connector_launcher_service_image_get_shared_widget_info(
  screen_connector_launcher_service_image_h handle,
  char** shared_widget_info);

int screen_connector_launcher_service_image_get_tbm_surface_info(
  screen_connector_launcher_service_image_h handle,
  tbm_surface_info_s** tbm_surface_info);

int screen_connector_launcher_service_image_get_image_file(
  screen_connector_launcher_service_image_h handle,
  int32_t* fd, uint32_t* size);

int screen_connector_launcher_service_image_get_file_path(
  screen_connector_launcher_service_image_h handle,
  char** file_path);

int screen_connector_launcher_service_image_get_file_group(
  screen_connector_launcher_service_image_h handle,
  char** file_group);

#ifdef __cplusplus
}
#endif

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_INCLUDE_SCREEN_CONNECTOR_LAUNCHER_SERVICE_H_
