/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_TIZEN_REMOTE_SURFACE_MANAGER_INTERNAL_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_TIZEN_REMOTE_SURFACE_MANAGER_INTERNAL_H_

#include <stdint.h>
#include <tbm_surface.h>
#include <tizen-remote-surface-client-protocol.h>
#include <wayland-extension/tizen-extension-client-protocol.h>
#include <wayland-tbm-client.h>

#include "screen_connector_common/handle.h"
#include "screen_connector_common/wl_surface.h"
#include "screen_connector_launcher_service/tizen_remote_surface_internal.h"

namespace screen_connector {

class TizenRemoteSurfaceManager {
 public:
  TizenRemoteSurfaceManager();
  virtual ~TizenRemoteSurfaceManager();

  TizenRemoteSurface* CreateTizenRemoteSurface(uint32_t res,
      std::shared_ptr<WlSurface> surface,
      Direction direction,
      int32_t x, int32_t y,
      std::string shared_widget_info,
      uint32_t serial);

 private:
  struct tizen_remote_surface_manager* tzrs_mgr_ = nullptr;
  struct wayland_tbm_client* tbm_client_ = nullptr;
  struct wl_tbm* tbm_ = nullptr;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_TIZEN_REMOTE_SURFACE_MANAGER_INTERNAL_H_
