/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_EVAS_EVENT_INTERFACE_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_EVAS_EVENT_INTERFACE_H_

#include <stdint.h>

#include <string>

#include "screen_connector_common/export.h"
#include "screen_connector_common/evas_object.h"
#include "screen_connector_launcher_service/direction.h"
#include "screen_connector_launcher_service/error.h"
#include "screen_connector_launcher_service/image_type.h"

namespace screen_connector {

class EXPORT IEvasEvent {
 public:
  virtual void OnEvasPrepareEvent(const EvasObject& image,
                                  ImageType image_type,
                                  Direction direction,
                                  int32_t x,
                                  int32_t y,
                                  const std::string& shared_widget_info,
                                  uint32_t serial) = 0;
  virtual void OnEvasStopEvent(uint32_t serial) = 0;
  virtual void OnEvasErrorEvent(Error error, uint32_t serial) = 0;
  virtual void OnEvasCleanUpEvent(uint32_t serial) = 0;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_EVAS_EVENT_INTERFACE_H_
