/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_LAUNCHER_SERVICE_EVAS_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_LAUNCHER_SERVICE_EVAS_H_

#include <memory>
#include <string>

#include "screen_connector_common/evas_object.h"
#include "screen_connector_common/export.h"
#include "screen_connector_launcher_service/launcher_service.h"
#include "screen_connector_launcher_service_evas/evas_event_interface.h"

namespace screen_connector {

class EXPORT LauncherServiceEvas : public LauncherService,
                                   public LauncherService::IEventListener,
                                   public IEvasEvent {
 public:
  LauncherServiceEvas(std::shared_ptr<EvasObject> win);
  virtual ~LauncherServiceEvas();

  const EvasObject& GetWindow();
  const EvasObject& GetImage();

 public:
  void OnEvasPrepareEvent(const EvasObject& image,
                          ImageType type,
                          Direction direction,
                          int32_t x,
                          int32_t y,
                          const std::string& shared_widget_info,
                          uint32_t serial) override;
  void OnEvasStopEvent(uint32_t serial) override;
  void OnEvasErrorEvent(Error error,
                        uint32_t serial) override;
  void OnEvasCleanUpEvent(uint32_t serial) override;

 private:
  void OnPrepareEvent(std::shared_ptr<RawImage> raw_image,
                      uint32_t serial);
  void OnStopEvent(uint32_t serial);
  void OnErrorEvent(Error error,
                    uint32_t serial);
  void OnCleanUpEvent(uint32_t serial);
  void OnResetEvent(uint32_t serial);

 private:
  class Impl;
  std::unique_ptr<Impl> impl_;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_LAUNCHER_SERVICE_EVAS_H_
