/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <dlog.h>

#include "screen_connector_remote_surface_evas/util.h"

#ifdef LOG_TAG
#undef LOG_TAG
#endif

#define LOG_TAG "SC_REMOTE_SURFACE"

using namespace std;
namespace screen_connector {
namespace util {

  std::shared_ptr<WlSurface> GetWlSurface(const EvasObject& win) {
    struct wl_surface* surface;
    Ecore_Wl2_Window* wl_win;
    Ecore_Evas *ee = ecore_evas_ecore_evas_get(
        evas_object_evas_get(win.GetRaw()));

    wl_win = ecore_evas_wayland2_window_get(ee);
    if (!wl_win) {
      LOGE("failed to get wl_win");
      return nullptr;
    }

    surface = ecore_wl2_window_surface_get(wl_win);
    if (!surface) {
      LOGE("failed to get surface");
      return nullptr;
    }
    return std::shared_ptr<WlSurface>(new WlSurface(surface, false));
  }

}  // namespace util
}  // namespace watchface_complication
