/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_SHARED_WIDGET_LAUNCH_SHARED_WIDGET_LAUNCH_H_
#define SCREEN_CONNECTOR_SHARED_WIDGET_LAUNCH_SHARED_WIDGET_LAUNCH_H_

#include <stdint.h>

#include <memory>
#include <string>

#include "screen_connector_common/export.h"
#include "screen_connector_common/wl2_window.h"
#include "screen_connector_shared_widget_launch/prepare_state.h"

namespace screen_connector {

class EXPORT SharedWidgetLaunch {
 public:
  class EXPORT IEventListener {
   public:
    virtual void OnPrepareEvent(PrepareState state, uint32_t serial) = 0;
  };

  explicit SharedWidgetLaunch(std::shared_ptr<Wl2Window> wl2_win,
                              IEventListener* listener);
  virtual ~SharedWidgetLaunch();

  void PrepareDone(const std::string& shared_widget_info,
                   PrepareState state,
                   uint32_t serial);

 private:
  class Impl;
  std::unique_ptr<Impl> impl_;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_SHARED_WIDGET_LAUNCH_SHARED_WIDGET_LAUNCH_H_
