#include <gtest/gtest.h>
#include <gmock/gmock.h>
#include <iostream>
#include <stdbool.h>
#include <stdexcept>
#include <glib.h>
#include "screen_connector_remote_surface/buffer_event_interface.h"
#include "screen_connector_remote_surface/remote_surface_implementation.h"
#include "screen_connector_remote_surface/remote_surface.h"

using namespace std;
using ::testing::AtLeast;

GMainLoop *mainloop = NULL;
class SimpleRs : public screen_connector::RemoteSurface {
 public:
   enum Event {
     None,
     Added,
     Removed,
     Changed
   };

   Event curEvent;
   string curInstId;
   int curType = -1;
   SimpleRs(const std::string& id,
     screen_connector::RemoteSurface::Type type, bool mock, Event evType)
       : screen_connector::RemoteSurface(id, type, nullptr, mock),
          curEvent(evType) {
   }
   void OnBufferAdded(const std::string& appId,
                      const std::string& instId, int pid) override {
     cout << "OnBufferAdded  " << instId << endl;
     if (curEvent == Added && g_main_loop_is_running(mainloop)) {
       g_main_loop_quit(mainloop);
       curInstId = instId;
       cout << "OnBufferAdded done  ?? " << curInstId << endl;
     }
   }
   void OnBufferRemoved(const std::string& appId,
                      const std::string& instId, int pid) override {

     cout << "OnBufferRemoved  " << instId << endl;
     if (curEvent == Removed && g_main_loop_is_running(mainloop)) {
       g_main_loop_quit(mainloop);
       curInstId = instId;
       cout << "OnBufferRemoved done  ?? " << curInstId << endl;
     }
   }
   void OnBufferChanged(int type, std::shared_ptr<screen_connector::WlBuffer> tbm,
                        int fd, uint32_t size, uint32_t time) override {
     cout << "OnBufferChanged event " << type << endl;
     if (curEvent == Changed && g_main_loop_is_running(mainloop)) {
       g_main_loop_quit(mainloop);
       curType = type;
       cout << "OnBufferChanged event done " << curType << endl;
     }
   }
};

class SCRemoteSurface : public ::testing::Test {
 public:
  string testId = "org.tizen.screen_connector.test.appid.instid";
  void RunMainLoop() {
    g_main_loop_run(mainloop);
  }
  virtual void SetUp() {
    mainloop = g_main_loop_new(NULL, FALSE);
  }
  virtual void TearDown() {
    g_main_loop_unref(mainloop);
	mainloop = NULL;
  }
};

TEST_F(SCRemoteSurface, SCRemoteSurface_CONST) {
  SimpleRs *rs = new SimpleRs(testId.c_str(),
    screen_connector::RemoteSurface::WIDGET, true, SimpleRs::Event::None);
  EXPECT_NE(rs, nullptr);
  delete rs;
}

TEST_F(SCRemoteSurface, SCRemoteSurface_ADDED) {
  SimpleRs *rs = new SimpleRs(testId.c_str(),
    screen_connector::RemoteSurface::WIDGET, true, SimpleRs::Event::Added);
  RunMainLoop();
  EXPECT_EQ(testId, rs->curInstId);
  delete rs;
}

TEST_F(SCRemoteSurface, SCRemoteSurface_CHANGED) {
  SimpleRs *rs = new SimpleRs(testId.c_str(),
    screen_connector::RemoteSurface::WIDGET, true, SimpleRs::Event::Changed);
  RunMainLoop();
  EXPECT_EQ(TIZEN_REMOTE_SURFACE_BUFFER_TYPE_TBM, rs->curType);
  delete rs;
}

TEST_F(SCRemoteSurface, SCRemoteSurface_REMOVED) {
  SimpleRs *rs = new SimpleRs(testId.c_str(),
    screen_connector::RemoteSurface::WIDGET, true, SimpleRs::Event::Removed);
  RunMainLoop();
  EXPECT_EQ(testId, rs->curInstId);
  delete rs;
}
